==========
Developing
==========

The following sections list contributing guidelines as well a detailed description of
design of the package that may help to understand much better how and where to implement
new features. This information should help make writing and contributing new
functionality much more straightforward.

.. toctree::
   :maxdepth: 3

   guide
   design
